LexToPlus Python version<br/>
Require:<br/>

-lextoplus<br/>
```
  pip install lextoplus
```
Example:
```
from lextoplus import LexToPlus
lexto = LexToPlus()
print(lexto.wordInstance('ทดสอบตัดคำภาษาไทย'))
```